@@ -9,5 +9,6 @@ def makeTupleActionProcessorHandler(mainController: MainController):
     processor = TupleActionProcessor(
         tupleActionProcessorName=gisDiagramActionProcessorName,
         additionalFilt=gisDiagramFilt,
-        defaultDelegate=mainController)
+        defaultDelegate=mainController,
+    )
     return processor
